@@ -67,11 +67,10 @@ class NormalSongTab(Gtk.ScrolledWindow):
         col_album = Widgets.TreeViewColumnText('Album', album, text=2)
         self.treeview.append_column(col_album)
 
-        if list_name != 'Cached':
-            delete = Gtk.CellRendererPixbuf(icon_name='user-trash-symbolic')
-            col_delete = Widgets.TreeViewColumnIcon('Delete', delete)
-            self.treeview.append_column(col_delete)
-            self.connect('key-press-event', self.on_key_pressed)
+        delete = Gtk.CellRendererPixbuf(icon_name='user-trash-symbolic')
+        col_delete = Widgets.TreeViewColumnIcon('Delete', delete)
+        self.treeview.append_column(col_delete)
+        self.connect('key-press-event', self.on_key_pressed)
         
     def on_key_pressed(self, widget, event):
         if event.keyval == Gdk.KEY_Delete:
@@ -79,6 +78,9 @@ class NormalSongTab(Gtk.ScrolledWindow):
             model, paths = selection.get_selected_rows()
             # paths needs to be reversed, or else an IndexError throwed.
             for path in reversed(paths):
+                if self.list_name == 'Cached':
+                    self.app.playlist.remove_song_from_cached_db(
+                            model[path][3])
                 model.remove(model[path].iter)
 
     def on_treeview_row_activated(self, treeview, path, column):
@@ -92,6 +94,8 @@ class NormalSongTab(Gtk.ScrolledWindow):
         elif index == 2:
             self.app.search.search_album(song['album'])
         elif index == 3:
+            if self.list_name == 'Cached':
+                self.app.playlist.remove_song_from_cached_db(song['rid'])
             model.remove(model[path].iter)
 
     def on_drag_data_get(self, treeview, drag_context, sel_data, info, 
@@ -124,6 +128,7 @@ class PlayList(Gtk.Box):
         self.cache_timeout = 0
 
         self.playlist_menu = Gtk.Menu()
+        self.playlist_advice_disname = ''
 
         self.conn = sqlite3.connect(Config.SONG_DB)
         self.cursor = self.conn.cursor()
@@ -140,6 +145,9 @@ class PlayList(Gtk.Box):
         col_name = Gtk.TreeViewColumn('List Name', list_disname, 
                 text=0, editable=2)
         self.treeview_left.append_column(col_name)
+        #col_name.props.max_width = 30
+        #col_name.props.fixed_width = 30
+        #col_name.props.min_width = 15
         tree_sel = self.treeview_left.get_selection()
         tree_sel.connect('changed', self.on_tree_selection_left_changed)
         self.treeview_left.enable_model_drag_dest(
@@ -264,8 +272,6 @@ class PlayList(Gtk.Box):
                 songs = self.get_all_cached_songs_from_db()
             else:
                 songs = playlists[list_name]
-            if list_name not in ('Cached', 'Caching'):
-                self.append_menu_item_to_playlist_menu(disname, list_name)
             self.init_tab(list_name, songs)
 
     def init_tab(self, list_name, songs):
@@ -328,6 +334,7 @@ class PlayList(Gtk.Box):
             return
         liststore.append(Widgets.song_dict_to_row(song))
         self.curr_playing = [list_name, len(liststore)-1, ]
+        self.locate_curr_song()
         if use_mv:
             self.app.player.load_mv(song)
         else:
@@ -489,6 +496,7 @@ class PlayList(Gtk.Box):
         if self.prev_playing is None:
             return
         self.curr_playing[1] = self.prev_playing
+        self.locate_curr_song()
         if use_mv:
             self.app.player.load_mv(prev_song)
         else:
@@ -497,6 +505,7 @@ class PlayList(Gtk.Box):
     def play_next_song(self, repeat, use_mv=False):
         next_song = self.get_next_song(repeat=repeat)
         self.curr_playing[1] = self.next_playing
+        self.locate_curr_song()
         if use_mv:
             self.app.player.load_mv(next_song)
         else:
@@ -521,6 +530,7 @@ class PlayList(Gtk.Box):
             left_path += 1
         selection_left = self.treeview_left.get_selection()
         selection_left.select_path(left_path)
+        print('left path:', left_path)
         self.app.popup_page(self.app_page)
 
     # DB operations
@@ -549,6 +559,10 @@ class PlayList(Gtk.Box):
         result = self.cursor.execute(sql, (rid, ))
         return result.fetchone()
 
+    def remove_song_from_cached_db(self, rid):
+        sql = 'DELETE FROM `songs` WHERE rid=?'
+        self.cursor.execute(sql, (rid, ))
+
     def get_song_path_in_liststore(self, liststore, rid, pos=3):
         i = 0
         for item in liststore:
@@ -564,7 +578,6 @@ class PlayList(Gtk.Box):
             return
         old_name = self.liststore_left[path][0]
         self.liststore_left[path][0] = new_name
-        self.update_item_name_in_playlist_menu(old_name, new_name)
 
     def on_add_playlist_button_clicked(self, button):
         list_name = str(time.time())
@@ -574,7 +587,6 @@ class PlayList(Gtk.Box):
         selection = self.treeview_left.get_selection()
         selection.select_iter(_iter)
         self.init_tab(list_name, [])
-        self.append_menu_item_to_playlist_menu(disname, list_name)
 
     def on_remove_playlist_button_clicked(self, button):
         selection = self.treeview_left.get_selection()
@@ -588,7 +600,6 @@ class PlayList(Gtk.Box):
             return
         self.notebook.remove_page(index)
         model.remove(_iter)
-        self.remove_menu_item_from_playlist_menu(disname)
 
     def on_export_playlist_button_clicked(self, button):
         def do_export(button):
@@ -664,40 +675,46 @@ class PlayList(Gtk.Box):
         dialog.run()
         dialog.destroy()
 
-    # other button can activate this function
-    def append_menu_item_to_playlist_menu(self, disname, list_name):
-        menu_item = Gtk.MenuItem(disname)
-        menu_item.connect('activate', self.on_menu_item_active)
-        menu_item.list_name = list_name
-        self.playlist_menu.append(menu_item)
+    def advise_new_playlist_name(self, disname):
+        self.playlist_advice_disname = disname
 
-    def remove_menu_item_from_playlist_menu(self, disname):
-        item = self.get_item_from_playlist_menu(disname)
-        self.playlist_menu.remove(item)
+    def on_advice_menu_item_activated(self, advice_item):
+        list_name = str(time.time())
+        self.liststore_left.append([self.playlist_advice_disname,
+                                    list_name,
+                                    True])
+        self.init_tab(list_name, [])
+        advice_item.list_name = list_name
+        self.on_menu_item_activated(advice_item)
 
-    def update_item_name_in_playlist_menu(self, old_name, new_name):
-        item = self.get_item_from_playlist_menu(old_name)
-        item.set_label(new_name)
-
-    def get_item_from_playlist_menu(self, disname):
-        menu = self.playlist_menu
-        items = menu.get_children()
-        for item in items:
-            if item.get_label() == disname:
-                return item
-
-    def on_menu_item_active(self, menu_item):
+    def on_menu_item_activated(self, menu_item):
         list_name = menu_item.list_name
-        songs = self.playlist_menu.songs
+        songs = menu_item.get_parent().songs
         self.add_songs_to_playlist(songs, list_name)
 
     def popup_playlist_menu(self, button, songs):
-        def set_pos(menu, user_data=None):
-            event = Gtk.get_current_event().button
-            alloc = button.get_allocation()
-            return (event.x, event.y + alloc.height, True)
-
         menu = self.playlist_menu
+        while len(menu.get_children()) > 0:
+            menu.remove(menu.get_children()[0])
+
+        for item in self.liststore_left:
+            if item[1] in ('Cached', 'Caching'):
+                continue
+            menu_item = Gtk.MenuItem(item[0])
+            menu_item.list_name = item[1]
+            menu_item.connect('activate', self.on_menu_item_activated)
+            menu.append(menu_item)
+
+        if self.playlist_advice_disname:
+            sep_item = Gtk.SeparatorMenuItem()
+            menu.append(sep_item)
+            advice_item = Gtk.MenuItem('+ ' + self.playlist_advice_disname)
+            advice_item.connect('activate',
+                    self.on_advice_menu_item_activated)
+            advice_item.set_tooltip_text(
+                    _('Create this playlist and add songs into it'))
+            menu.append(advice_item)
+
         menu.songs = songs
         menu.show_all()
         menu.popup(None, None, None, None, 1, 
